@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 /*
  * This file is part of PHP Copy/Paste Detector (PHPCPD).
  *
@@ -33,17 +33,17 @@ final class CodeCloneFile
         $this->id        = $this->name . ':' . $this->startLine;
     }
 
-    public function getId(): string
+    public function id(): string
     {
         return $this->id;
     }
 
-    public function getName(): string
+    public function name(): string
     {
         return $this->name;
     }
 
-    public function getStartLine(): int
+    public function startLine(): int
     {
         return $this->startLine;
     }
