@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 /*
  * This file is part of PHP Copy/Paste Detector (PHPCPD).
  *
@@ -11,24 +11,17 @@ namespace SebastianBergmann\PHPCPD\Detector;
 
 use SebastianBergmann\PHPCPD\CodeCloneMap;
 use SebastianBergmann\PHPCPD\Detector\Strategy\AbstractStrategy;
-use Symfony\Component\Console\Helper\ProgressBar;
 
 final class Detector
 {
     /**
-     * @var \SebastianBergmann\PHPCPD\Detector\Strategy\AbstractStrategy
+     * @var AbstractStrategy
      */
     private $strategy;
 
-    /**
-     * @var \Symfony\Component\Console\Helper\ProgressBar
-     */
-    private $progressBar;
-
-    public function __construct(AbstractStrategy $strategy, ProgressBar $progressBar = null)
+    public function __construct(AbstractStrategy $strategy)
     {
-        $this->strategy    = $strategy;
-        $this->progressBar = $progressBar;
+        $this->strategy = $strategy;
     }
 
     public function copyPasteDetection(iterable $files, int $minLines = 5, int $minTokens = 70, bool $fuzzy = false): CodeCloneMap
@@ -47,10 +40,6 @@ final class Detector
                 $result,
                 $fuzzy
             );
-
-            if ($this->progressBar !== null) {
-                $this->progressBar->advance();
-            }
         }
 
         return $result;
