@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 /*
  * This file is part of PHP Copy/Paste Detector (PHPCPD).
  *
@@ -9,77 +9,77 @@
  */
 namespace SebastianBergmann\PHPCPD\Log;
 
+use const ENT_COMPAT;
+use function file_put_contents;
+use function function_exists;
+use function htmlspecialchars;
+use function mb_convert_encoding;
+use function ord;
+use function preg_replace;
+use function strlen;
+use function utf8_encode;
+use DOMDocument;
 use SebastianBergmann\PHPCPD\CodeCloneMap;
 
 abstract class AbstractXmlLogger
 {
     /**
-     * @var \DOMDocument
+     * @var DOMDocument
      */
     protected $document;
 
     /**
-     * Constructor.
+     * @var string
      */
+    private $filename;
+
     public function __construct(string $filename)
     {
-        $this->document               = new \DOMDocument('1.0', 'UTF-8');
+        $this->document               = new DOMDocument('1.0', 'UTF-8');
         $this->document->formatOutput = true;
 
         $this->filename = $filename;
     }
 
-    /**
-     * Processes a list of clones.
-     */
     abstract public function processClones(CodeCloneMap $clones);
 
-    /**
-     * Writes the XML document to the file.
-     */
     protected function flush(): void
     {
-        \file_put_contents($this->filename, $this->document->saveXML());
+        file_put_contents($this->filename, $this->document->saveXML());
     }
 
-    /**
-     * Converts a string to UTF-8 encoding.
-     */
     protected function convertToUtf8(string $string): string
     {
         if (!$this->isUtf8($string)) {
-            if (\function_exists('mb_convert_encoding')) {
-                $string = \mb_convert_encoding($string, 'UTF-8');
+            if (function_exists('mb_convert_encoding')) {
+                $string = mb_convert_encoding($string, 'UTF-8');
             } else {
-                $string = \utf8_encode($string);
+                $string = utf8_encode($string);
             }
         }
 
         return $string;
     }
 
-    /**
-     * Checks a string for UTF-8 encoding.
-     */
-    protected function isUtf8(string $string): string
+    protected function isUtf8(string $string): bool
     {
-        $length = \strlen($string);
+        $length = strlen($string);
 
         for ($i = 0; $i < $length; $i++) {
-            if (\ord($string[$i]) < 0x80) {
+            if (ord($string[$i]) < 0x80) {
                 $n = 0;
-            } elseif ((\ord($string[$i]) & 0xE0) == 0xC0) {
+            } elseif ((ord($string[$i]) & 0xE0) === 0xC0) {
                 $n = 1;
-            } elseif ((\ord($string[$i]) & 0xF0) == 0xE0) {
+            } elseif ((ord($string[$i]) & 0xF0) === 0xE0) {
                 $n = 2;
-            } elseif ((\ord($string[$i]) & 0xF0) == 0xF0) {
+            } elseif ((ord($string[$i]) & 0xF0) === 0xF0) {
                 $n = 3;
             } else {
                 return false;
             }
 
             for ($j = 0; $j < $n; $j++) {
-                if ((++$i == $length) || ((\ord($string[$i]) & 0xC0) != 0x80)) {
+                if ((++$i === $length) || ((ord($string[$i]) & 0xC0) !== 0x80)) {
                     return false;
                 }
             }
@@ -88,24 +88,16 @@ abstract class AbstractXmlLogger
         return true;
     }
 
-    /**
-     * Escapes a string for inclusion inside an XML tag.
-     *
-     * Converts the string to UTF-8, substitutes the unicode replacement
-     * character for every character disallowed in XML, and escapes
-     * special characters.
-     */
     protected function escapeForXml(string $string): string
     {
         $string = $this->convertToUtf8($string);
 
-        // Substitute the unicode replacement character for disallowed chars
-        $string = \preg_replace(
+        $string = preg_replace(
             '/[^\x09\x0A\x0D\x{0020}-\x{D7FF}\x{E000}-\x{FFFD}]/u',
             "\xEF\xBF\xBD",
             $string
         );
 
-        return \htmlspecialchars($string, \ENT_COMPAT, 'UTF-8');
+        return htmlspecialchars($string, ENT_COMPAT, 'UTF-8');
     }
 }
